@@ -5,10 +5,7 @@
 # see LICENSE for full details
 ##############################################
 from squaternion.squaternion import Quaternion
-from squaternion.squaternion import euler2quat
-from squaternion.squaternion import quat2euler
-from squaternion.squaternion import quatNorm
-
+from squaternion.squaternion import Axis
 
 try:
     from importlib.metadata import version # type: ignore
